==> eslint-plugin-angular-0.0.13.tgz: package/test/ng_module_name.js <==
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

var eslint = require('../node_modules/eslint/lib/eslint'),
    ESLintTester = require('eslint-tester');

//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

var eslintTester = new ESLintTester(eslint);
eslintTester.addRuleTest('rules/ng_module_name', {
    valid: [{
        code: 'app.module("eslintModule", []);',
        args: [1, 'eslint']
    }, {
        code: 'app.module("module");',
        args: [1, 'eslint']
    }, {
        code: 'app.module("eslintModule", []);',
        args: [1, /^eslint/]
    }, {
        code: 'app.module("eslintModule", []);',
        args: [1, '/^eslint/']
    }, {
        code: 'app.module("eslintModule", []);',
        args: [1, undefined]
    }],
    invalid: [
        {
            code: 'app.module("module", []);',
            args: [1, 'eslint'],
            errors: [{ message: 'The module module should be prefixed by eslint'}]
        }, {
            code: 'app.module("ESLintModule", []);',
            args: [1, 'eslint'],
            errors: [{ message: 'The ESLintModule module should be prefixed by eslint'}]
        }, {
            code: 'app.module("module", []);',
            args: [1, /^eslint/],
            errors: [{ message: 'The module module should follow this pattern: /^eslint/'}]
        }, {
            code: 'app.module("module", []);',
            args: [1, "/^eslint/"],
            errors: [{ message: 'The module module should follow this pattern: /^eslint/'}]
        }, {
            code: 'app.module("ngModule", []);',
            args: [1, /^ng/],
            errors: [{ message: 'The ngModule module should not start with "ng". This is reserved for AngularJS modules'}]
        }
    ]
});

==> eslint-plugin-angular-0.5.0.tgz: package/test/ng_module_name.js <==
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

var rule = require('../rules/ng_module_name'),
    RuleTester = require("eslint").RuleTester;

//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

var eslintTester = new RuleTester();
eslintTester.run('ng_module_name', rule, {
    valid: [{
        code: 'app.module("eslintModule", []);',
        options: ['eslint']
    }, {
        code: 'app.module("module");',
        options: ['eslint']
    }, {
        code: 'app.module("eslintModule", []);',
        options: [/^eslint/]
    }, {
        code: 'app.module("eslintModule", []);',
        options: ['/^eslint/']
    }, {
        code: 'app.module("eslintModule", []);',
        options: [undefined]
    }],
    invalid: [
        {
            code: 'app.module("module", []);',
            options: ['eslint'],
            errors: [{ message: 'The module module should be prefixed by eslint'}]
        }, {
            code: 'app.module("ESLintModule", []);',
            options: ['eslint'],
            errors: [{ message: 'The ESLintModule module should be prefixed by eslint'}]
        }, {
            code: 'app.module("module", []);',
            options: [/^eslint/],
            errors: [{ message: 'The module module should follow this pattern: /^eslint/'}]
        }, {
            code: 'app.module("module", []);',
            options: ["/^eslint/"],
            errors: [{ message: 'The module module should follow this pattern: /^eslint/'}]
        }, {
            code: 'app.module("ngModule", []);',
            options: [/^ng/],
            errors: [{ message: 'The ngModule module should not start with "ng". This is reserved for AngularJS modules'}]
        }
    ]
});
